@@ -7,6 +7,7 @@ from google.protobuf.empty_pb2 import Empty
 from grpc import ChannelConnectivity
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
+import featurestore
 import featurestore.core.CoreService_pb2 as pb
 from featurestore.core import CoreService_pb2_grpc, interactive_console
 from featurestore.core.auth import AuthWrapper
@@ -35,7 +36,7 @@ class Client:
     ):
         self._client_config = config
         options = [
-            ("grpc.primary_user_agent", "feature-store-py-cli/0.1.2"),
+            ("grpc.primary_user_agent", "feature-store-py-cli/0.3.0"),
         ]
         if secure:
             default_root_certs = pkg_resources.resource_filename(
@@ -81,6 +82,10 @@ class Client:
         self.auth = AuthWrapper(self._stub)
         self.projects = Projects(self._stub)
         self.jobs = Jobs(self._stub)
+        if self.get_version() != featurestore.__version__:
+            raise Exception(
+                f"Feature Store Client v{featurestore.__version__} is not compatible with Server v{self.get_version()}"
+            )
 
     def __enter__(self):
         return self
