@@ -1,4 +1,5 @@
 import re
+import sys
 import webbrowser
 
 import grpc
@@ -29,8 +30,8 @@ class AuthWrapper:
         self._get_access_token_external = method
 
     def logout(self):
-        try:
-            self._obtain_token()
+        is_success, token_or_error = self._obtain_token()
+        if is_success:
             if not AuthWrapper._is_personal_access_token(self._props["token"].data):
                 request = pb.LogoutRequest()
                 request.refresh_token = self._props["token"].data
@@ -39,10 +40,11 @@ class AuthWrapper:
                 self._access_token_expire = None
             ConfigUtils.delete_property(self._props, ConfigUtils.TOKEN_KEY)
             print("You have been logged out.")
-        except AuthException:
+        else:
             print("You are not logged in.")
 
     def login(self):
+        sys.tracebacklimit = None
         for response in self._stub.Login(Empty()):
             if response.HasField("login_url"):
                 try:
@@ -56,14 +58,19 @@ class AuthWrapper:
             elif response.HasField("refresh_token"):
                 self.set_auth_token(response.refresh_token)
             else:
+                sys.tracebacklimit = 0
                 raise AuthException("Incorrect response")
 
     def set_auth_token(self, token):
+        sys.tracebacklimit = None
         ConfigUtils.store_token(self._props, token)
         if not AuthWrapper._is_personal_access_token(token):
             self._access_token = None
             self._access_token_expire = None
-            self._obtain_token()
+            is_success, token_or_error = self._obtain_token()
+            if not is_success:
+                sys.tracebacklimit = 0
+                raise AuthException(token_or_error)
 
     @staticmethod
     def _is_personal_access_token(token: str) -> bool:
@@ -77,29 +84,31 @@ class AuthWrapper:
 
     def _obtain_token(self):
         if self._get_access_token_external is not None:
-            return self._get_access_token_external()
+            return True, self._get_access_token_external()
         elif ConfigUtils.TOKEN_KEY not in self._props:
-            raise AuthException(
-                "You are not authenticated. Set personal access token or execute client.auth.login() method"
+            return (
+                False,
+                "You are not authenticated. Set personal access token or execute client.auth.login() method",
             )
         elif AuthWrapper._is_personal_access_token(ConfigUtils.get_token(self._props)):
-            return ConfigUtils.get_token(self._props)
+            return True, ConfigUtils.get_token(self._props)
         elif self._is_access_token_expired():
             request = pb.RefreshTokenRequest()
             request.refresh_token = ConfigUtils.get_token(self._props)
             try:
                 resp = self._stub.GetAccessToken(request)
             except grpc.RpcError as e:
-                raise AuthException(
-                    f"The authentication token is no longer valid. Please login again. Auth Server response: {str(e)}"
+                return (
+                    False,
+                    f"The authentication token is no longer valid. Please login again.",
                 )
 
             self._access_token = resp.access_token
             ConfigUtils.store_token(self._props, resp.refresh_token)
             self._access_token_expire = resp.expires_in
-            return self._access_token
+            return True, self._access_token
         else:
-            return self._access_token
+            return True, self._access_token
 
     def __repr__(self):
         return "This class wraps together methods related to Authentication"
