@@ -89,6 +89,11 @@ class FeatureSets:
         response = self._stub.ListFeatureSets(request)
         return [FeatureSet(self._stub, fs) for fs in response.feature_sets]
 
+    def list_feature_classifiers(self):
+        request = Empty()
+        response = self._stub.ListFeatureClassifiers(request)
+        return response.feature_classifiers
+
     def __repr__(self):
         return Utils.pretty_print_proto(self._project)
 
