@@ -146,7 +146,11 @@ class SnowflakeTable:
 
 class JdbcTable:
     def __init__(
-        self, connection_url, table="", query="", partition_options=None,
+        self,
+        connection_url,
+        table="",
+        query="",
+        partition_options=None,
     ):
         if not (table or query):
             raise ValueError("Table or query is required!")
@@ -282,7 +286,10 @@ class ParquetFolder:
 
 class JSONFolder:
     def __init__(
-        self, root_folder, partition_pattern="", multiline=False,
+        self,
+        root_folder,
+        partition_pattern="",
+        multiline=False,
     ):
         self.root_folder = root_folder
         self.multiline = multiline
