@@ -2,7 +2,7 @@ from abc import ABC, abstractmethod
 from concurrent.futures import ThreadPoolExecutor
 
 from .. import CoreService_pb2 as pb
-from .. import interactive_console
+from ..job_info import JobInfo
 
 
 class BaseJob(ABC):
@@ -11,8 +11,8 @@ class BaseJob(ABC):
         self._job_id = job_id
         self._result = None
         self._job = self._stub.GetJob(self._job_id)
-        self._progress = interactive_console.Progress(self._stub, self._job_id)
         self._thread_pool = ThreadPoolExecutor(5)
+        self._info = JobInfo(self._stub, self._job_id)
 
     @property
     def id(self):
@@ -26,6 +26,10 @@ class BaseJob(ABC):
     def done(self):
         return self.is_done()
 
+    @property
+    def child_job_ids(self):
+        return self._job.childJobIds
+
     @abstractmethod
     def _response_method(self, job_id):
         raise NotImplementedError(
@@ -43,7 +47,10 @@ class BaseJob(ABC):
         return self._result
 
     def show_progress(self):
-        self._progress.show()
+        self._info.show_progress()
+
+    def get_metrics(self):
+        return self._info.get_metrics()
 
     def __repr__(self):
-        return f"""Job(id={self.id}, type={self.job_type}, done={self.done})"""
+        return f"""Job(id={self.id}, type={self.job_type}, done={self.done}, childJobIds={self.child_job_ids})"""
