@@ -6,6 +6,10 @@ CATEGORICAL = FeatureSetApi.FeatureType.Name(FeatureSetApi.FeatureType.CATEGORIC
 NUMERICAL = FeatureSetApi.FeatureType.Name(FeatureSetApi.FeatureType.NUMERICAL)
 TEMPORAL = FeatureSetApi.FeatureType.Name(FeatureSetApi.FeatureType.TEMPORAL)
 TEXT = FeatureSetApi.FeatureType.Name(FeatureSetApi.FeatureType.TEXT)
+COMPOSITE = FeatureSetApi.FeatureType.Name(FeatureSetApi.FeatureType.COMPOSITE)
+AUTOMATIC_DISCOVERY = FeatureSetApi.FeatureType.Name(
+    FeatureSetApi.FeatureType.AUTOMATIC_DISCOVERY
+)
 
 
 class Feature:
@@ -74,6 +78,19 @@ class Feature:
         self._stub.UpdateFeatureDescription(update_request)
         self._refresh()
 
+    @property
+    def classifier(self):
+        return self._internal_feature.classifier
+
+    @classifier.setter
+    def classifier(self, value):
+        update_request = pb.FeatureStringFieldUpdateRequest()
+        update_request.new_value = value
+        update_request.absolute_feature_name = self._absolute_feature_name
+        update_request.header.CopyFrom(self._fs._feature_set_header)
+        self._stub.UpdateFeatureClassifier(update_request)
+        self._refresh()
+
     @property
     def importance(self):
         return self._internal_feature.importance
@@ -137,7 +154,7 @@ class FeatureProfile:
 
     @property
     def feature_type(self):
-        return FeatureSetApi.FeatureType.Name(
+        return FeatureSetApi.FeatureTypeInternal.FeatureType.Name(
             self._feature._internal_feature.profile.feature_type
         )
 
