@@ -13,8 +13,10 @@ from ..entities.feature import Feature
 from ..retrieve_holder import RetrieveHolder
 from ..schema import Schema
 from ..utils import Utils
+from .feature_set_schema import FeatureSetSchema
 from .ingest_job import IngestJob
 from .materialization_online_job import MaterializationOnlineJob
+from .recommendation import Recommendation
 from .user import User
 
 
@@ -308,6 +310,10 @@ class FeatureSet:
     def custom_data(self):
         return self._feature_set.custom_data
 
+    @property
+    def feature_classifiers(self):
+        return self._feature_set.feature_classifiers
+
     @custom_data.setter
     def custom_data(self, value):
         update_request = pb.FeatureSetCustomDataUpdateRequest()
@@ -327,7 +333,7 @@ class FeatureSet:
         if schema:
             request.schema.extend(schema._to_proto_schema())
         else:
-            request.schema.extend(self.get_schema()._to_proto_schema())
+            request.schema.extend(self.schema.get()._to_proto_schema())
         if affected_features:
             request.affected_features.extend(affected_features)
         response = self._stub.CreateNewFeatureSetVersion(request)
@@ -385,9 +391,12 @@ class FeatureSet:
         )
 
     def get_active_jobs(self, job_type=pb.JobType.Unknown):
+        self._get_jobs(True, job_type)
+
+    def _get_jobs(self, active, job_type=pb.JobType.Unknown):
         from ..collections.jobs import Jobs  # Lazy import to avoid circular reference
 
-        request = pb.ListJobsRequest(active=True)
+        request = pb.ListJobsRequest(active=active)
         request.feature_set.CopyFrom(self._feature_set)
         request.job_type = job_type
         resp = self._stub.ListJobs(request)
@@ -412,7 +421,6 @@ class FeatureSet:
     def ingest_async(
         self,
         source,
-        new_version_on_schema_change=False,
         start_date_time=None,
         end_date_time=None,
         credentials=None,
@@ -426,7 +434,6 @@ class FeatureSet:
             data_source = get_raw_data_location(source)
         request = pb.StartIngestJobRequest()
         request.feature_set.CopyFrom(self._feature_set)
-        request.new_version_on_schema_change = new_version_on_schema_change
         request.data_source.CopyFrom(data_source)
         CredentialsHelper.set_credentials(request, data_source, credentials)
         if start_date_time is not None:
@@ -440,14 +447,12 @@ class FeatureSet:
     def ingest(
         self,
         source,
-        new_version_on_schema_change=False,
         start_date_time=None,
         end_date_time=None,
         credentials=None,
     ):
         job = self.ingest_async(
             source,
-            new_version_on_schema_change,
             start_date_time,
             end_date_time,
             credentials,
@@ -506,12 +511,19 @@ class FeatureSet:
         response = self._stub.ListFeatureSetVersions(request)
         return [VersionDescription(version) for version in response.versions]
 
-    def get_schema(self):
-        return Schema.create_from(self)
+    @property
+    def schema(self):
+        return FeatureSetSchema(self._stub, self)
 
     def ingest_history(self):
         return IngestHistory(self._stub, self._feature_set)
 
+    def get_recommendations(self):
+        request = pb.GetRecommendationRequest()
+        request.feature_set.CopyFrom(self._feature_set)
+        response = self._stub.GetRecommendations(request)
+        return [Recommendation(self._stub, self, item) for item in response.matches]
+
     def __repr__(self):
         return Utils.pretty_print_proto(self._feature_set)
 
