@@ -15,10 +15,6 @@ class Ingest:
         self._ingest = ingest
 
     def retrieve(self):
-        if self._ingest.ingest_id == "-1":
-            raise NotImplementedError(
-                "Data ingested before system version 0.0.36 is not supported for retrieval via this API."
-            )
         return RetrieveHolder(
             self._stub, self._feature_set, "", "", self._ingest.ingest_id
         )
@@ -33,10 +29,6 @@ class Ingest:
         return job.get_result()
 
     def revert_async(self) -> RevertIngestJob:
-        if self._ingest.ingest_id == "-1":
-            raise NotImplementedError(
-                "Data ingested before system version 0.0.36 is not supported for retrieval via this API."
-            )
         request = pb.StartRevertIngestJobRequest()
         request.feature_set.CopyFrom(self._feature_set)
         request.ingest_id = self._ingest.ingest_id
