@@ -1,6 +1,7 @@
 import re
 
 from . import CoreService_pb2 as pb
+from . import FeatureSetProtoApi_pb2 as FeatureSetApi
 
 
 class FeatureSchemaSpecialData:
@@ -19,13 +20,25 @@ class FeatureSchemaSpecialData:
 
 class FeatureSchema:
     def __init__(
-        self, name, _data_type, special_data=None, nested_features_schema=None,
+        self,
+        name,
+        _data_type,
+        special_data=None,
+        nested_features_schema=None,
+        _feature_type="AUTOMATIC_DISCOVERY",
+        description="",
+        classifier="",
     ):
         self._data_type = _data_type
         self._name = name
         self._special_data = special_data or FeatureSchemaSpecialData()
         self._nested_features_schema = nested_features_schema or []
         self._schema = Schema(self._nested_features_schema, False)
+        self._validated_feature_type = FeatureSchema.get_and_validate_feature_type(
+            _feature_type
+        )
+        self._description = description
+        self._classifier = classifier
 
     @property
     def schema(self):
@@ -50,6 +63,32 @@ class FeatureSchema:
     def data_type(self, value):
         self._data_type = value
 
+    @property
+    def feature_type(self):
+        return FeatureSetApi.FeatureType.Name(self._validated_feature_type)
+
+    @feature_type.setter
+    def feature_type(self, value):
+        self._validated_feature_type = FeatureSchema.get_and_validate_feature_type(
+            value
+        )
+
+    @property
+    def description(self):
+        return self._description
+
+    @description.setter
+    def description(self, value):
+        self._description = value
+
+    @property
+    def classifier(self):
+        return self._classifier
+
+    @classifier.setter
+    def classifier(self, value):
+        self._classifier = value
+
     @property
     def schema(self):
         return self._schema
@@ -74,8 +113,22 @@ class FeatureSchema:
                 feature.special_data.sensitive,
             ),
             nested,
+            feature.profile.feature_type,
+            feature.description,
+            feature.classifier,
         )
 
+    @staticmethod
+    def get_and_validate_feature_type(feature_type):
+        valid_values = FeatureSetApi.FeatureType.keys()
+        if feature_type.upper() in valid_values:
+            FeatureSetApi.FeatureType.Value(feature_type.upper())
+        else:
+            raise Exception(
+                "Invalid feature type. Supported values are: "
+                + ", ".join(map(str, valid_values))
+            )
+
     def __repr__(self):
         return self.to_string()
 
@@ -169,6 +222,9 @@ class Schema:
                     demographic=feature_schema.special_data.demographic,
                     sensitive=feature_schema.special_data.sensitive,
                 ),
+                feature_type=feature_schema._validated_feature_type,
+                description=feature_schema.description,
+                classifier=feature_schema.classifier,
             )
             for feature_schema in self._feature_schemas
         ]
